==> nextcloud-27.1.3.tgz: nextcloud/apps/comments/l10n/es.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Has comentado",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Has comentado en %1$s",
    "You commented on {file}" : "Has comentado en  {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para archivos",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Te han mencionado en \"{file}\", en un comentario de un usuario que después ha sido eliminado",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} te mencionó en un comentario en “{file}”",
    "Files app plugin to add comments to files" : "Plugin de la app de Archivos para añadir comentarios a archivos.",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cacelar edición",
    "Post comment" : "Publicar comentario",
    "\"@\" for mentions, \":\" for emoji, \"/\" for smart picker" : "\"@\" para menciones, \":\" para emojis, \"/\" para selector inteligente",
    "No comments yet, start the conversation!" : "¡No hay comentarios, empieza la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "Failed to mark comments as read" : "Fallo al marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se pudo cargar la lista de comentarios",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} comentarios nuevos","{unread} comentarios nuevos"],
    "Comment" : "Comentar",
    "An error occurred while trying to edit the comment" : "Ocurrió un error intentando editar el comentario",
    "Comment deleted" : "Comentario borrado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error intentando borrar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error intentando crear el comentario",
    "%1$s commented" : "%1$s comentados",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sin leer","%n comentarios no leídos","%n comentarios no leídos"]
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-27.1.5.tgz: nextcloud/apps/comments/l10n/es.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "You commented" : "Has comentado",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Has comentado en %1$s",
    "You commented on {file}" : "Has comentado en  {file}",
    "%1$s commented on %2$s" : "%1$s comentados en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> para archivos",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Te han mencionado en \"{file}\", en un comentario de un usuario que después ha sido eliminado",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} te mencionó en un comentario en “{file}”",
    "Files app plugin to add comments to files" : "Plugin de la app de Archivos para añadir comentarios a archivos.",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "Cancel edit" : "Cacelar edición",
    "Post comment" : "Publicar comentario",
    "@ for mentions, : for emoji, / for smart picker" : "@ para menciones, : para emoji, / para selector inteligente",
    "Could not reload comments" : "No se pudieron recargar los comentarios",
    "No comments yet, start the conversation!" : "¡No hay comentarios, empieza la conversación!",
    "No more messages" : "No hay más mensajes",
    "Retry" : "Reintentar",
    "Failed to mark comments as read" : "Fallo al marcar los comentarios como leídos",
    "Unable to load the comments list" : "No se pudo cargar la lista de comentarios",
    "_1 new comment_::_{unread} new comments_" : ["1 comentario nuevo","{unread} comentarios nuevos","{unread} comentarios nuevos"],
    "Comment" : "Comentar",
    "An error occurred while trying to edit the comment" : "Ocurrió un error intentando editar el comentario",
    "Comment deleted" : "Comentario borrado",
    "An error occurred while trying to delete the comment" : "Ocurrió un error intentando borrar el comentario",
    "An error occurred while trying to create the comment" : "Ocurrió un error intentando crear el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentario sin leer","%n comentarios no leídos","%n comentarios no leídos"]
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
